# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "0.1.1"
FULL_VERSION = "0.1.1.1.0"

CLOTH_CONFIG_VERSION = "11.1.106"
CURSEFORGE_ID = "824728"
HEXCASTING_VERSION = "0.11.2-pre-701"
INLINE_VERSION = "1.0.1"
JEI_VERSION = "15.0.0.12"
JETBRAINS_ANNOTATIONS_VERSION = "23.0.0"
KOTLIN_VERSION = "1.7.20"
MINECRAFT_VERSION = "1.20.1"
MOD_I_D = "moreiotas"
MOD_NAME = "MoreIotas"
MOD_VERSION = "0.1.1"
MODRINTH_ID = "Jmt7p37B"
ORG_GRADLE_DAEMON = "false"
ORG_GRADLE_JAVA_INSTALLATIONS_FROM_ENV = "JAVA_17_HOME"
ORG_GRADLE_JVMARGS = "-Xmx3G"
PATCHOULI_VERSION = "82"
PAUCAL_VERSION = "0.6.0-pre-118"
PEHKUI_VERSION = "3.7.6"
